@@ -1,6 +1,6 @@
 package XML::TreePuller;
 
-our $VERSION = '0.1.2_01';
+our $VERSION = '0.1.3_01';
 
 use strict;
 use warnings;
@@ -11,13 +11,18 @@ use XML::LibXML::Reader;
 
 use XML::TreePuller::Element;
 use XML::TreePuller::Constants;
+use XML::CompactTree;
 
 our $NO_XS;
 
 BEGIN {
-	if (! defined(eval { require XML::CompactTree::XS; })) {
+	
+	if ($ENV{XML_TREEPULLER_NO_XS}) {
+		$NO_XS = $ENV{XML_TREEPULLER_NO_XS};
+	}
+	
+	if (! $NO_XS && ! defined(eval { require XML::CompactTree::XS; })) {
 		$NO_XS = 1;
-		require XML::CompactTree;
 	}
 
 }
@@ -521,6 +526,22 @@ Gentle introduction to parsing using Atom as an example.
 
 High performance processing of Wikipedia dump files.
 
+=item XML::TreePuller::CookBook::Patterns
+
+=item XPath Tutorial
+
+=over 4
+
+=item 
+
+http://www.zvon.org/xxl/XPathTutorial/Output/example1.html
+
+=item 
+
+http://www.w3schools.com/xpath/
+
+=back
+
 =item MediaWiki::DumpFile::Pages
 
 Object oriented recursive descent parser that maps Mediawiki XML dump files into
